@@ -24,8 +24,8 @@ mbpls <- function(dudiY, ktabX, scale = TRUE, option = c("uniform", "none"), sca
         nf <- 2
     
     ## Only works with centred pca (dudi.pca with center=TRUE) with uniform row weights
-    #if (!any(dudi.type(dudiY$call) == c(3,4)))
-    #    stop("Only implemented for centred pca")
+    if (!any(dudi.type(dudiY$call) == c(3,4)))
+        stop("Only implemented for centred pca")
 
     # Vérifier la formule / arrondi
     #if (any(dudiY$lw != 1/nrow(dudiY$tab)))
@@ -38,7 +38,7 @@ mbpls <- function(dudiY, ktabX, scale = TRUE, option = c("uniform", "none"), sca
     ## -------------------------------------------------------------------------------
     
     ## Preparation of the data frames
-    Y <- scalewt(as.matrix(dudiY$tab), wt = dudiY$lw, center = TRUE, scale = scale)
+    Y <- as.matrix(dudiY$tab)
     nblo  <- length(ktabX$blo)
     Xk <- lapply(unclass(ktabX)[1 : nblo], scalewt, wt = ktabX$lw, center = TRUE, scale = scale)
       
@@ -142,10 +142,10 @@ mbpls <- function(dudiY, ktabX, scale = TRUE, option = c("uniform", "none"), sca
 
         lX1[, h] <- res$lX[, h] / sqrt(sum(res$lX[, h]^2))
         ## use ginv to avoid NA in coefficients (collinear system)
-        W[, h]  <- tcrossprod(MASS::ginv(crossprod(X)), X) %*% res$lX[, h]
+        W[, h]  <- tcrossprod(ginv(crossprod(X)), X) %*% res$lX[, h]
         
         ## Deflation of the Xk datasets on the global components T
-        Xk <- lapply(Xk, function(y) lm.wfit(x = as.matrix(res$lX[, h]), y = y, w = res$lw)$residuals)
+        Xk <- lapply(Xk, function(y) stats::lm.wfit(x = as.matrix(res$lX[, h]), y = y, w = res$lw)$residuals)
         X  <- as.matrix(cbind.data.frame(Xk))
     }
 
@@ -177,19 +177,6 @@ mbpls <- function(dudiY, ktabX, scale = TRUE, option = c("uniform", "none"), sca
     res$XYcoef <- lapply(1:ncolY, function(x) t(apply(sweep(res$faX, 2 , res$Yco[x,] / norm.li, "*"), 1, cumsum)))
     names(res$XYcoef) <- colnames(dudiY$tab)
     
-    ##  Computing the intercept
-    X <- cbind.data.frame(lapply(unclass(ktabX)[1 : nblo], scalewt, wt = dudiY$lw, center = FALSE, scale = scale))
-    if (any(apply(X, 2, weighted.mean, w = dudiY$lw) < sqrt(.Machine$double.eps)) == FALSE & scale == TRUE) {
-        ## i.e. center=F, scale=T
-        meanY <- apply(sweep(as.matrix(dudiY$tab), 2, sqrt(apply(dudiY$tab, 2, varwt, wt = dudiY$lw)), "/"), 2, weighted.mean, w = dudiY$lw)
-        meanX <- apply(sweep(as.matrix(X), 2, sqrt(apply(X, 2, varwt, wt = dudiY$lw)), "/"), 2, weighted.mean, w = dudiY$lw)
-    } else {
-        meanY  <- apply(as.matrix(dudiY$tab), 2, weighted.mean, w = dudiY$lw)
-        meanX  <- apply(as.matrix(X), 2, weighted.mean, w = dudiY$lw)    
-    }
-    res$intercept <- lapply(1:ncolY, function(x)  (meanY[x] - meanX %*% res$XYcoef[[x]]))
-    names(res$intercept) <- colnames(dudiY$tab)
-    
     ##-----------------------------------------------------------------------
     ##   		Variable and block importances
     ##-----------------------------------------------------------------------
@@ -214,10 +201,11 @@ mbpls <- function(dudiY, ktabX, scale = TRUE, option = c("uniform", "none"), sca
     ##			         Modify the outputs
     ##-----------------------------------------------------------------------
     
-    if (scannf == TRUE){
-        barplot(res$eig[1:res$rank])
+    if (scannf) {
+        graphics::barplot(res$eig[1:res$rank])
         cat("Select the number of global components: ")
         res$nf <- as.integer(readLines(n = 1))
+        messageScannf(match.call(), res$nf)
     }
 
     if(res$nf > res$rank)
@@ -229,9 +217,8 @@ mbpls <- function(dudiY, ktabX, scale = TRUE, option = c("uniform", "none"), sca
     res$Tc1 <- do.call("rbind", res$Tc1)
     res$TlX <- do.call("rbind", res$TlX)
     
-    res <- modifyList(res, lapply(res[c("Yc1", "Yco", "lY", "Tc1", "TlX", "cov2", "faX", "vip", "vipc", "bip", "bipc")], function(x) x[, 1:res$nf, drop = FALSE]))
+    res <- utils::modifyList(res, lapply(res[c("Yc1", "Yco", "lY", "Tc1", "TlX", "cov2", "faX", "vip", "vipc", "bip", "bipc")], function(x) x[, 1:res$nf, drop = FALSE]))
     res$XYcoef <- lapply(res$XYcoef, function(x) x[, 1:res$nf, drop = FALSE])
-    res$intercept <- lapply(res$intercept, function(x) x[, 1:res$nf, drop = FALSE])
     res$call   <- match.call()
     class(res) <- c("multiblock", "mbpls")
     return(res)
